| kin_regr | R Documentation |
Returns from an ord_res object either the linear or the non-linear
regression of the degradation kinetics data.
kin_regr(x)
x |
an |
After the
analysis in the phase space for the determination of the reaction order,
det_order() performs either a linear or a non-linear
regression of the kinetic data, depending on whether the reaction order is
n=0 or n>0,
respectively. To access the regression object call kin_degr.
Returns either an nls or lm object based on the regression
performed by the function det_order().
det_order(), phase_space(), results(), stats::lm()
t <- c(0, 4, 8, 12, 16, 20)
conc <- c(1, 0.51, 0.24, 0.12, 0.07, 0.02)
dframe <- data.frame(t, conc)
res <- det_order(dframe)
kin_regr(res)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.