| phase_space | R Documentation |
Given an ord_res object, this function returns the linearized model
that best fits the data in the phase space.
ord_res object can be obtained using the function det_order().
phase_space(x)
x |
an |
Returns a lm class object.
det_order(), kin_regr(), results(), stats::lm()
t <- c(0, 4, 8, 12, 16, 20)
conc <- c(1, 0.51, 0.24, 0.12, 0.07, 0.02)
dframe <- data.frame(t, conc)
res <- det_order(dframe)
phase_space(res)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.